Skip to main contentCrate ingot_macros
Source - define_primitive_types
- Proc macro which defines primitive integers of various endianness
from 9 to 128 bits.
- define_tuple_trait_impls
- Defines
Header and Emit for tuple types up to length 16 elements.
- choice
- Attribute macro for a selection over one or more individual headers,
conditional on an input hint.
- Ingot
- Derive macro for defining individual protocol headers.
- Parse
- Derive macro for parsing complete packets, potentially spanning
several byte slices.